
using System;

namespace Calculator
{ 
	/// <summary>
	/// Operand, represented as double
	/// </summary>	
	public class Operand:INode
	{

		private double internalVal;
		
		/// <summary>
		/// Constructor for an operand
		/// </summary>
		/// <param name="d">
		/// A <see cref="System.Double"/>
		/// </param>
		public Operand(double d)
		{
			internalVal = d;
		}
		/// <summary>
		/// Return the operand value
		/// </summary>
		/// <returns>
		/// A <see cref="System.Double"/>
		/// </returns>
		public double InternalValue
		{
			get {return internalVal;}
			
			private set {internalVal = value;}
		}
		
		/// <summary>
		/// Implement double dispatch using this operand and the specific visitor passed as argument
		/// </summary>
		/// <param name="v">
		/// A <see cref="IVisitor"/>
		/// </param>
		public void Accept(IVisitor v)
		{
			v.Visit(this);
		}
		/// <summary>
		/// String representation of an operand
		/// </summary>
		/// <returns>
		/// A <see cref="System.String"/>
		/// </returns>
		public override string ToString ()
		{
			return string.Format("Operand: {0}", internalVal.ToString());
		}        
	}
}
